@@ -29,7 +29,7 @@ namespace math{
 
     virtual ~Matrix() {
       if (transposate) delete transposate;
-    };
+    }
  
 
     virtual unsigned int nRows() const = 0;
@@ -53,7 +53,7 @@ namespace math{
      * \brief substract lambda * line j to line i
      */
     void subLine(unsigned int i,unsigned int j,const T & lambda){
-      for(int k=0; k < nCols() ; ++k)
+      for(unsigned int k=0; k < nCols() ; ++k)
 	set(i , k ,  get(i, k) - ( get(j , k) * lambda ) );
     }
 
@@ -61,28 +61,31 @@ namespace math{
      * \brief multiply line i by lambda
      */
     void mulLine(unsigned int i,const T & lambda){
-      for(int k=0; k < nCols(); ++k)
+      for(unsigned int k=0; k < nCols(); ++k)
 	set(i , k,  get(i,k)  * lambda  );
     }
     
-    Matrix & transpose();
+    Matrix * transpose();
   };
   
   template< class T>
     class Transpose: public Matrix<T> {
     private :
       Matrix<T> & source;
-      
-     
+         
     public:
       Transpose(Matrix<T> & source_p)
 	: source(source_p) {
-      };
+      }
 
       unsigned int size() const{
 	return source.size();
       }
 
+    bool isVector() const {
+      return false;
+    }
+    
       unsigned int nRows() const {
 	return source.nCols();
       }
@@ -95,12 +98,12 @@ namespace math{
 	source.set(j,i,val);
       }
 
-    };
+  };
 
   // template code.
   template<class T>
   Vector<T>::Vector() {
-  };
+  }
 
   template<class T>
     Matrix<T>::Matrix() : 
@@ -110,18 +113,18 @@ namespace math{
   }
 
   template<class T>
-    Matrix<T> & Matrix<T>::transpose(){
+    Matrix<T> * Matrix<T>::transpose(){
     if (transposate == 0){
       transposate =new Transpose<T>(*this);
     }
-    return *transposate;
+    return transposate;
   }
   
   template<class T>
     unsigned int Matrix<T>::nCols() const{
    
     return this->size() / nRows();
-    };
+    }
 
   
 
